@@ -27,6 +27,7 @@ Copyright (c) Intel Corporation (2009-2017).
 #include "llvm/Option/ArgList.h"
 #include "llvm/Option/Option.h"
 #include "clang/Basic/OpenCLOptions.h"
+#include "LLVMSPIRVOpts.h"
 
 #include <list>
 
@@ -160,7 +161,7 @@ public:
   // Validates and prepares the effective options to pass to clang upon
   // compilation
   //
-  void processOptions(const char *pszOptions, const char *pszOptionsEx);
+  int processOptions(const char *pszOptions, const char *pszOptionsEx);
 
   //
   // Just validates the user supplied OpenCL compile options
@@ -186,6 +187,13 @@ public:
   std::string getEffectiveOptionsAsString() const;
 
   bool hasEmitSPIRV() const { return m_emitSPIRV; }
+
+  bool hasSPIRVExt() const { return m_hasSPIRVExt; }
+
+  SPIRV::TranslatorOpts::ExtensionsStatusMap getSPIRVExtStatusMap() const {
+    return m_SPIRVExtStatusMap;
+  }
+
   bool hasOptDisable() const { return m_optDisable; }
 
 private:
@@ -195,6 +203,8 @@ private:
   llvm::SmallVector<const char *, 16> m_effectiveArgsRaw;
   std::string m_sourceName;
   bool m_emitSPIRV;
+  bool m_hasSPIRVExt = false;
+  SPIRV::TranslatorOpts::ExtensionsStatusMap m_SPIRVExtStatusMap = {};
   bool m_optDisable;
 };
 
